==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/pt-BR/admin/users/general.php <==
<?php


return array(
    'activated_help_text' => 'Este usuário pode efetuar login',
    'activated_disabled_help_text' => 'Você não pode alterar o status de ativação da sua própria conta.',
    'assets_user'       => 'Bens atribuidos a :name',
    'bulk_update_warn'	=> 'Você está prestes a editar as propriedades de: user_count users. Por favor, note que você não pode alterar seus próprios atributos de usuário usando este formulário e deve fazer edições de seu próprio usuário individualmente.',
    'bulk_update_help'	=> 'Este formulário lhe permite atualizar múltiplos ativos de uma vez. Apenas preencha os campos que você precisa alterar. Qualquer campo deixado em branco permanecerá inalterado.',
    'current_assets'    => 'Artivos atribuídos atualmente a este usuário',
    'clone'             => 'Clonar Usuário',
    'contact_user'      => 'Contato :name',
    'edit'              => 'Editar Usuário',
    'filetype_info'     => 'Tipo de arquivos permitidos são png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, e rar.',
    'history_user'      => 'Histórico para :name',
	'info'				=> 'Informações',
    'restore_user'		=> 'Clique aqui para restaurá-los.',
    'last_login'        => 'Último Login',
    'ldap_config_text'  => 'As configurações do LDAP podem ser encontradas em \'Administrador > Definições\'. A localização (opcional) selecionada será definida para todos os usuários importados.',
    'print_assigned'    => 'Imprimir todos atribuídos',
    'software_user'     => 'Check-out de software para :name',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'Ver Usuário :name',
    'usercsv'           => 'Arquivo CSV',
    'two_factor_admin_optin_help' => 'As configurações de admin atuais permitem a aplicação seletiva de autenticação de dois passos.  ',
    'two_factor_enrolled' => 'Dispositivo 2FA Registrado ',
    'two_factor_active'   => 'A2P Ativo ',
    );

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/pt-BR/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Este usuário pode efetuar login',
    'activated_disabled_help_text' => 'Você não pode alterar o status de ativação da sua própria conta.',
    'assets_user'       => 'Bens atribuidos a :name',
    'bulk_update_warn'	=> 'Você está prestes a editar as propriedades de: user_count users. Por favor, note que você não pode alterar seus próprios atributos de usuário usando este formulário e deve fazer edições de seu próprio usuário individualmente.',
    'bulk_update_help'	=> 'Este formulário lhe permite atualizar múltiplos ativos de uma vez. Apenas preencha os campos que você precisa alterar. Qualquer campo deixado em branco permanecerá inalterado.',
    'current_assets'    => 'Artivos atribuídos atualmente a este usuário',
    'clone'             => 'Clonar Usuário',
    'contact_user'      => 'Contato :name',
    'edit'              => 'Editar Usuário',
    'filetype_info'     => 'Tipo de arquivos permitidos são png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, e rar.',
    'history_user'      => 'Histórico para :name',
    'info'				=> 'Informações',
    'restore_user'		=> 'Clique aqui para restaurá-los.',
    'last_login'        => 'Último Login',
    'ldap_config_text'  => 'As configurações do LDAP podem ser encontradas em \'Administrador > Definições\'. A localização (opcional) selecionada será definida para todos os usuários importados.',
    'print_assigned'    => 'Imprimir todos atribuídos',
    'software_user'     => 'Check-out de software para :name',
    'send_email_help'   => 'Você deve fornecer um endereço de e-mail para este usuário enviar credenciais. As credenciais de e-mail só podem ser feitas na criação do usuário. As senhas são armazenadas em hash unidirecional e não podem ser recuperadas uma vez salva.',
    'view_user'         => 'Ver Usuário :name',
    'usercsv'           => 'Arquivo CSV',
    'two_factor_admin_optin_help' => 'As configurações de admin atuais permitem a aplicação seletiva de autenticação de dois passos.  ',
    'two_factor_enrolled' => 'Dispositivo 2FA Registrado ',
    'two_factor_active'   => 'A2P Ativo ',
    'user_deactivated'  => 'User is de-activated',
    'activation_status_warning' => 'Do not change activation status',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Remove Group Memberships',
    'warning_deletion' => 'WARNING:',
    'warning_deletion_information' => 'You are about to delete the :count user(s) listed below. Super admin names are highlighted in red.',
    'update_user_asssets_status' => 'Update all assets for these users to this status',
    'checkin_user_properties' => 'Check in all properties associated with these users',
];
